package com.applovin.enterprise.apps.demoapp.ads.max.banner;

import android.graphics.Color;
import android.os.Bundle;
import android.view.View;
import android.view.ViewGroup;
import android.widget.Button;
import android.widget.FrameLayout;

import com.adjust.sdk.Adjust;
import com.adjust.sdk.AdjustAdRevenue;
import com.adjust.sdk.AdjustConfig;
import com.applovin.enterprise.apps.demoapp.R;
import com.applovin.enterprise.apps.demoapp.ui.BaseAdActivity;
import com.applovin.mediation.MaxAd;
import com.applovin.mediation.MaxAdRevenueListener;
import com.applovin.mediation.MaxAdViewAdListener;
import com.applovin.mediation.MaxError;
import com.applovin.mediation.ads.MaxAdView;
import com.applovin.sdk.AppLovinSdkUtils;

import androidx.annotation.NonNull;

import java.util.concurrent.atomic.AtomicBoolean;
/**
 * An {@link android.app.Activity} used to show AppLovin MAX banner ads.
 * <p>
 * Created by santoshbagadi on 2019-09-10.
 */
public class ProgrammaticBannerAdActivity
        extends BaseAdActivity
        implements MaxAdViewAdListener, MaxAdRevenueListener
{
    private MaxAdView adView;
    private Button showButton;
    private boolean clicked = false;
    final AtomicBoolean atomicBoolean = new AtomicBoolean(false);
    @Override
    protected void onCreate(Bundle savedInstanceState)
    {
        super.onCreate( savedInstanceState );
        setContentView( R.layout.activity_programmatic_banner_ad );
        setTitle( R.string.activity_programmatic_banners );

        setupCallbacksRecyclerView();
        //wilder 20240717 new
        showButton = findViewById( R.id.show_ad_button );
        showButton.setOnClickListener( v -> {
            //showAd();
        } );
        //adView = new MaxAdView( "YOUR_AD_UNIT_ID", this );
        adView = new MaxAdView( "8c0f35f3e6517995", this ); //wilder for official custom event
        //adView = new MaxAdView( "a4c83d3509fc2d35", this );//wilder 2023 for js-tag
        //adView = new MaxAdView("dc329a3606b7d711", this); //wilder 2024 for test line
        //adView = new MaxAdView("1ec89a1224cc5c42", this); //wilder 2024 for rave

        adView.setListener( this );
        adView.setRevenueListener( this );

        // Set the height of the banner ad based on the device type.
        final boolean isTablet = AppLovinSdkUtils.isTablet( this );
        final int heightPx = AppLovinSdkUtils.dpToPx( this, isTablet ? 90 : 50 );
        // Banner width must match the screen to be fully functional.
        adView.setLayoutParams( new FrameLayout.LayoutParams( ViewGroup.LayoutParams.MATCH_PARENT, heightPx ) );

        // Need to set the background or background color for banners to be fully functional.
        adView.setBackgroundColor( Color.WHITE );

        final ViewGroup rootView = (ViewGroup) findViewById( android.R.id.content );
        rootView.addView( adView );

        // Load the first ad.
        showButton.setVisibility(View.INVISIBLE); //wilder 2024
        adView.loadAd();
    }

    @Override
    protected void onDestroy()
    {
        super.onDestroy();

        adView.destroy();
    }

    //region MAX Ad Listener
	//wilder 2024 add 
    private void showAd() {
        final ViewGroup rootView = (ViewGroup) findViewById(android.R.id.content);
        clicked = !clicked;
        if (clicked) {
            rootView.addView(adView);
            //showButton.setText("show");
        }else {
            rootView.removeView(adView);
            //showButton.setText("hide");
        }
    }
    @Override
    public void onAdLoaded(@NonNull final MaxAd ad) {
        showButton.setVisibility(View.VISIBLE);
        //if (atomicBoolean.compareAndSet(false, true))
            logCallback();
    }

    @Override
    public void onAdLoadFailed(@NonNull final String adUnitId, @NonNull final MaxError maxError) { logCallback(); }

    @Override
    public void onAdHidden(@NonNull final MaxAd ad) { logCallback(); }

    @Override
    public void onAdDisplayFailed(@NonNull final MaxAd ad, @NonNull final MaxError maxError) { logCallback(); }

    @Override
    public void onAdDisplayed(@NonNull final MaxAd ad) {
        logCallback();
        //showButton.setVisibility(View.INVISIBLE);
    }

    @Override
    public void onAdClicked(@NonNull final MaxAd ad) { logCallback(); }

    @Override
    public void onAdExpanded(@NonNull final MaxAd ad) { logCallback(); }

    @Override
    public void onAdCollapsed(@NonNull final MaxAd ad) { logCallback(); }

    //endregion

    //region MAX Ad Revenue Listener

    @Override
    public void onAdRevenuePaid(@NonNull final MaxAd maxAd)
    {
        logCallback();

        AdjustAdRevenue adjustAdRevenue = new AdjustAdRevenue( AdjustConfig.AD_REVENUE_APPLOVIN_MAX );
        adjustAdRevenue.setRevenue( maxAd.getRevenue(), "USD" );
        adjustAdRevenue.setAdRevenueNetwork( maxAd.getNetworkName() );
        adjustAdRevenue.setAdRevenueUnit( maxAd.getAdUnitId() );
        adjustAdRevenue.setAdRevenuePlacement( maxAd.getPlacement() );

        Adjust.trackAdRevenue( adjustAdRevenue );
    }

    //endregion
}
